@@ -13,33 +13,33 @@ class AGC:
     enable: bool = True
     delete_existing: bool = False  # Delete all models already existing in the directory?
     # 1-6 6 creates user galaxy by asking questions
-    base_galaxies: List[int] = field(
+    base_galaxies: List = field(
         default_factory=lambda: [1, 2, 3, 4, 5, 6])
     inhomogenous: bool = True  # Add homogenieties?
     symmetric: bool = False  # Keep galaxies symmetric
     # options are Casa_Sim, Gaussian, No_Corrupt, Tres, Casa_5
     corruption_method: str = 'Tres'
-    variables_to_vary: List[str] = field(default_factory=lambda: ['Base', 'Inclination', 'Beams', 'Radial_Motions',
+    variables_to_vary: List = field(default_factory=lambda: ['Base', 'Inclination', 'Beams', 'Radial_Motions',
                                          'Flare', 'Arms', 'Bar', 'Mass', 'Channelwidth', 'SNR', 'Warp', 'Mass', 'Beam_Size'])
     # Each base is created with the variations in the following parameters if they are listed to be varied.
-    inclination: List[float] = field(default_factory=lambda: [
+    inclination: List= field(default_factory=lambda: [
                                      15., 20., 30., 50., 70., 80., 88., 90.])
-    pa: List[float] = field(default_factory=lambda: [0., 360.])
-    warp: List[float] = field(default_factory=lambda: [
+    pa: List = field(default_factory=lambda: [0., 360.])
+    warp: List = field(default_factory=lambda: [
                               [0.15, 0.05], [0.05, 0.2]])
-    radial_motions: List[float] = field(default_factory=lambda: [-10., -20.])
-    dispersion: List[float] = field(default_factory=lambda: [[30.0, 8.0]])
+    radial_motions: List = field(default_factory=lambda: [-10., -20.])
+    dispersion: List = field(default_factory=lambda: [[30.0, 8.0]])
     #The flare, arms and bar will be swapped when incuded in the swap lisr
-    beams:  List[float] = field(default_factory=lambda: [
+    beams:  List = field(default_factory=lambda: [
                                 2., 4., 5., 6., 8., 10., 12.])
     # Beam across the major axis. This also set the distance as the size in kpc will be determined by Wang 2016 from the SBR profile
-    snr: List[float] = field(default_factory=lambda: [0.5, 1., 3., 5.])
+    snr: List = field(default_factory=lambda: [0.5, 1., 3., 5.])
     # These  are average signal to noise ratios
-    channelwidth: List[float] = field(default_factory=lambda: [2.])
+    channelwidth: List = field(default_factory=lambda: [2.])
 
-    beam_size: List[float] = field(default_factory=lambda: [[5., 5., 0.]])
+    beam_size: List = field(default_factory=lambda: [[5., 5., 0.]])
     #Resolution of the beam in arcsec
-    masses:  List[float] = field(default_factory=lambda: [2.5e11])
+    masses:  List = field(default_factory=lambda: [2.5e11])
     # The channel dependency
     # 'Options are independent, sinusoidal, hanning
     channel_dependency: str = 'sinusoidal'
@@ -52,11 +52,11 @@ class ROC:
     add_template: bool = False
     remove_template: bool = False
     delete_existing: bool = False
-    base_galaxies: List[str] = field(default_factory=lambda: [
+    base_galaxies: List = field(default_factory=lambda: [
                                      'M_83', 'Circinus', 'NGC_5023', 'NGC_2903', 'NGC_3198', 'NGC_5204', 'UGC_1281', 'UGC_7774', 'ESO_223_G009'])
-    variables_to_vary: List[str] = field(
+    variables_to_vary: List = field(
         default_factory=lambda: ['Beams', 'SNR'])
-    beams: List[float] = field(default_factory=lambda: [2., 4., 6., 8., -1.])
+    beams: List = field(default_factory=lambda: [2., 4., 6., 8., -1.])
     # Beam across the major axis. This also set the distance as the size in kpc
     #will be determined by Wang 2016 from the SBR profile. -1 means the maximum possible for the ROC.
     # These  are average signal to noise ratios
@@ -65,7 +65,7 @@ class ROC:
     max_degradation_factor: float = 1.6
     # This is the maximum difference between the shifted template and the final template. If the shift factor is bigger we will smooth and regrid the template before the noise calculations.
     #A lower number  is for speed and low memory usage, a high number provides beter integrateion between the noise and the template. If lower than minimum_degradation_factor it will be set to the minimum_degradation_factor
-    snr: List[float] = field(default_factory=lambda: [0.5, 1., 3.])
+    snr: List = field(default_factory=lambda: [0.5, 1., 3.])
 
 
 @dataclass
